# Record of Contributions

Taken from the Turing Way.
*The `contributors.md` file and the contributors table in the `README file` together form the record of contributions .*

We recognise all contributions and acknowledge our community members fairly.
For example, using [all contributors bot](https://allcontributors.org) we update the contributors table with each person's name, where the emoji keys indicate the different tasks they have done (see the [README file]()).
We understand that different contributions mean different things to people and may translate differently towards their personal interest, skill development, value exchange and advancement of their careers.

Individual contributors are welcome to provide their details under the section "Personal Highlights from Contributors".
Organisational support and collaborations are listed in the section, "Collaborating Organisations".
Each organisation's name and details will be listed separately followed by contribution details of each individual contributor from that organisation.

Please see the [community handbook](https://the-turing-way.netlify.app/community-handbook/acknowledgement) for details on how you can be fairly acknowledged for your work.

## Personal Highlights from Contributors

Please use this section to highlight your personal experiences in The project and community.
You can also describe the impact the project may have on you or your team members such as in promoting reproducible, ethical, collaborative and inclusive research practices.

This record can be used in your personal or professional portfolio (profile, CV, resume) by describing features you have enhanced, goals you have accomplished, skills you gained, opportunities you receive, personal connections you make, individuals you support and values you create through your involvement in the project

See this entry as an example by Kirstie Whitaker, the project lead:

### Kirstie Whitaker

* Role: Project Member - 
* GitHub id: 
* ORCID: 
* Short bio:

* Personal highlights:

* More information:

**Contributors names are added alphabetically**

<!---A--->
## A
